# __init__.py

# Metadata
__version__ = '0.2.0'
__author__ = 'Drestanto Muhammad Dyasputro'
__author_email__ = 'dyas@live.com'
__license__ = 'MIT'

# Importing the necessary classes from the fractal_forest module
from .fractal import Fractal
